@@ -9,6 +9,17 @@ from os.path import join
 import shutil
 
 
+CARGO_TOML_ORIG = "Cargo.toml.orig"
+CARGO_TOML = "Cargo.toml"
+
+
+def get_egg_info_path(path, package):
+    for root, dirs, files in os.walk(path):
+        for dir in dirs:
+            if dir == "{}.egg-info".format(package.replace("-", "_")):
+                return join(path, join(root, dir))
+
+
 def download_package_source(url, ecosystem, package, version, dir_path):
     print("fetching {}-{} in {} ecosystem from {}".format(package, version, ecosystem, url))
 
@@ -30,15 +41,22 @@ def download_package_source(url, ecosystem, package, version, dir_path):
         files = os.listdir(dir_path)
         assert len(files) == 1
         path = "{}/{}".format(dir_path, files[0])
+        if ecosystem == CARGO:
+            if CARGO_TOML in os.listdir(path) and CARGO_TOML_ORIG in os.listdir(path):
+                os.remove(join(path, CARGO_TOML))
+                os.rename(join(path, CARGO_TOML_ORIG), join(path, CARGO_TOML))
     elif ecosystem == PIP:
         files = os.listdir(dir_path)
         if len(files) == 1:
             # for tar.gz extractions
             path = "{}/{}".format(dir_path, files[0])
             files = os.listdir(path)
-            egginfo = "{}.egg-info".format(package)
-            if egginfo in files:
-                shutil.rmtree(join(path, egginfo), ignore_errors=True)
+
+            # if egg built
+            egginfo = get_egg_info_path(path, package)
+            if egginfo:
+                shutil.rmtree(egginfo, ignore_errors=True)
+
             pkginfo = "PKG-INFO"
             if pkginfo in files:
                 os.remove(join(path, pkginfo))
