@@ -13,9 +13,6 @@ import os
 from version_differ.download import download_package_source, get_package_version_source_url
 from version_differ.common import *
 
-CARGO_TOML_ORIG = "Cargo.toml.orig"
-CARGO_TOML_ORIG_TXT = "Cargo.toml.orig.txt"
-
 
 class VersionDifferOutput:
     def __init__(self):
@@ -91,7 +88,8 @@ def get_commit_of_release(tags, package, version):
         r"^(?:.*[^1-9])?{}$".format(version_formatted_for_regex),
         # 2. check if and only if crate name and version string is present
         # besides non-alphanumeric, e.g., to distinguish guppy vs guppy-summaries
-        r"^.*{}\W*v?\W*{}$".format(package, version_formatted_for_regex),
+        r"^.*{}\W*-?_?v?-?_?\W*{}$".format(package, version_formatted_for_regex),
+        r"^.*{}\W*-?_?v?-?_?\W*{}$".format(version_formatted_for_regex, package),
     ]
 
     for pattern in patterns:
@@ -170,17 +168,6 @@ def get_version_diff_stats(ecosystem, package, old, new, repo_url=None):
     else:
         output = get_version_diff_stats_registry(ecosystem, package, old, new)
 
-        if ecosystem == CARGO:
-            if CARGO_TOML_ORIG_TXT in output.diff:
-                output.diff[CARGO_TOML_ORIG] = output.diff[CARGO_TOML_ORIG_TXT]
-                output.diff.pop(CARGO_TOML_ORIG_TXT)
-            if CARGO_TOML_ORIG_TXT in output.old_version_filelist:
-                output.old_version_filelist.discard(CARGO_TOML_ORIG_TXT)
-                output.old_version_filelist.add(CARGO_TOML_ORIG)
-            if CARGO_TOML_ORIG_TXT in output.new_version_filelist:
-                output.new_version_filelist.discard(CARGO_TOML_ORIG_TXT)
-                output.new_version_filelist.add(CARGO_TOML_ORIG)
-
     return output
 
 
@@ -206,8 +193,6 @@ def get_version_diff_stats_registry(ecosystem, package, old, new):
             if ecosystem == CARGO:
                 output.old_version_git_sha = get_git_sha_from_cargo_crate(old_path)
 
-                if CARGO_TOML_ORIG in os.listdir(old_path):
-                    os.rename(join(old_path, CARGO_TOML_ORIG), join(old_path, CARGO_TOML_ORIG_TXT))
         else:
             return output
 
@@ -217,9 +202,6 @@ def get_version_diff_stats_registry(ecosystem, package, old, new):
             # currently only cargo provides git sha
             if ecosystem == CARGO:
                 output.new_version_git_sha = get_git_sha_from_cargo_crate(new_path)
-
-                if CARGO_TOML_ORIG in os.listdir(new_path):
-                    os.rename(join(new_path, CARGO_TOML_ORIG), join(new_path, CARGO_TOML_ORIG_TXT))
         else:
             return output
 
@@ -236,6 +218,46 @@ def get_version_diff_stats_registry(ecosystem, package, old, new):
     return output
 
 
+def get_package_code_and_version_diff_stats_registry(ecosystem, package, old, new):
+    output = VersionDifferOutput()
+    output.old_version = old
+    output.new_version = new
+
+    temp_dir_old = tempfile.TemporaryDirectory()
+    temp_dir_new = tempfile.TemporaryDirectory()
+
+    url = get_package_version_source_url(ecosystem, package, old)
+    if url:
+        old_path = download_package_source(url, ecosystem, package, old, temp_dir_old.name)
+        # currently only cargo provides git sha
+        if ecosystem == CARGO:
+            output.old_version_git_sha = get_git_sha_from_cargo_crate(old_path)
+
+    else:
+        return output
+
+    url = get_package_version_source_url(ecosystem, package, new)
+    if url:
+        new_path = download_package_source(url, ecosystem, package, new, temp_dir_new.name)
+        # currently only cargo provides git sha
+        if ecosystem == CARGO:
+            output.new_version_git_sha = get_git_sha_from_cargo_crate(new_path)
+    else:
+        return output
+
+    repo_old, oid_old = init_git_repo(old_path)
+    repo_new, oid_new = init_git_repo(new_path)
+
+    setup_remote(repo_old, new_path)
+
+    output.diff = get_diff_stats(old_path, oid_old, oid_new)
+
+    output.new_version_filelist = get_repository_file_list(new_path, oid_new)
+    output.old_version_filelist = get_repository_file_list(old_path, oid_old)
+
+    return temp_dir_old, temp_dir_new, output
+
+
 def init_git_repo(path):
     repo = init_repository(path)
     index = repo.index
@@ -269,7 +291,6 @@ def get_diff_stats_from_git_diff(uni_diff_text):
 
     for patched_file in patch_set:
         file_path = patched_file.path  # file name
-
         ad_lines = [
             line.value for hunk in patched_file for line in hunk if line.is_added and line.value.strip() != ""
         ]  # the row number of deleted lines
